@@ -22,12 +22,12 @@
 
 #include "appearancegtk2.h"
 #include <QFile>
-#include <KDebug>
 #include <QStringList>
 #include <QDir>
-#include <qdiriterator.h>
-#include <KProcess>
-#include <KStandardDirs>
+#include <QDirIterator>
+#include <QDebug>
+#include <QProcess>
+#include <QStandardPaths>
 
 bool AppearanceGTK2::loadSettings(const QString& path)
 {
@@ -36,8 +36,8 @@ bool AppearanceGTK2::loadSettings(const QString& path)
     bool canRead = configFile.open(QIODevice::ReadOnly | QIODevice::Text);
     
     if(canRead) {
-        kDebug() << "The gtk2 config file exists...";
-        QMap<QString, QString> foundSettings = readSettingsTuples(&configFile);
+//         qDebug() << "The gtk2 config file exists...";
+        const QMap<QString, QString> foundSettings = readSettingsTuples(&configFile);
 
         m_settings["theme"] = foundSettings["gtk-theme-name"];
         m_settings["icon"] = foundSettings["gtk-icon-theme-name"];
@@ -60,7 +60,7 @@ QString AppearanceGTK2::themesGtkrcFile(const QString& themeName) const
         while(it.hasNext()) {
             it.next();
             if(it.fileName()=="gtkrc") {
-                kDebug() << "\tgtkrc file found at : " << it.filePath();
+//                 qDebug() << "\tgtkrc file found at : " << it.filePath();
                 return it.filePath();
             }
         }
@@ -69,13 +69,13 @@ QString AppearanceGTK2::themesGtkrcFile(const QString& themeName) const
     return QString();
 }
 
-bool AppearanceGTK2::saveSettings(const QString& gtkrcFile)
+bool AppearanceGTK2::saveSettings(const QString& gtkrcFile) const
 {
     QFile gtkrc(gtkrcFile);
     gtkrc.remove();
 
     if(!gtkrc.open(QIODevice::WriteOnly | QIODevice::Text)) {
-        kDebug() << "There was unable to write the file .gtkrc-2.0";
+        qWarning() << "There was unable to write the file .gtkrc-2.0";
         return false;
     }
 
@@ -108,23 +108,23 @@ bool AppearanceGTK2::saveSettings(const QString& gtkrcFile)
     flow << "gtk-icon-theme-name=\""<< m_settings["icon"] << "\"\n";
     flow << "gtk-fallback-icon-theme=\"" << m_settings["icon_fallback"] << "\"\n";
     flow << "gtk-toolbar-style=" << m_settings["toolbar_style"] << "\n";
-    flow << "gtk-menu-images=" << m_settings["show_icons_buttons"] << "\n";
-    flow << "gtk-button-images=" << m_settings["show_icons_menus"] << "\n";
+    flow << "gtk-menu-images=" << m_settings["show_icons_menus"] << "\n";
+    flow << "gtk-button-images=" << m_settings["show_icons_buttons"] << "\n";
     
     //we're done with the  ~/.gtk-2.0 file
     gtkrc.close();
     
     //TODO: do we really need the linked file?
     if(QFile::remove(gtkrcFile+"-kde4"))
-        kDebug() << "ready to create the symbolic link";
+        qDebug() << "ready to create the symbolic link";
     
     if( !QFile::link(gtkrcFile, gtkrcFile+"-kde4") )
-        kDebug() << "Couldn't create the symboling link to .gtkrc-2.0-kde4 :(";
-    else
-        kDebug() << "Symbolic link created for .gtkrc-2.0-kde4 :D";
+        qWarning() << "Couldn't create the symboling link to .gtkrc-2.0-kde4 :(";
+//     else
+//         qDebug() << "Symbolic link created for .gtkrc-2.0-kde4 :D";
     
     if(gtkrcFile==defaultConfigFile())
-        KProcess::startDetached(KStandardDirs::findExe("reload_gtk_apps"));
+        QProcess::startDetached(QStandardPaths::findExecutable("reload_gtk_apps"));
     
     return true;
 }
@@ -137,7 +137,7 @@ QString AppearanceGTK2::defaultConfigFile() const
 QStringList AppearanceGTK2::installedThemes() const
 {
     QFileInfoList availableThemes;
-    foreach(const QString& themesDir, KGlobal::dirs()->findDirs("xdgdata-apps", "../themes")) {
+    foreach(const QString& themesDir, QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, "themes", QStandardPaths::LocateDirectory)) {
         QDir root(themesDir);
         availableThemes += root.entryInfoList(QDir::NoDotAndDotDot|QDir::AllDirs);
     }
