@@ -21,15 +21,15 @@
  */
 
 #include "appearancegtk3.h"
-#include <KDebug>
-#include <KStandardDirs>
 #include <QFile>
 #include <QDir>
+#include <QDebug>
+#include <QStandardPaths>
 
 QStringList AppearanceGTK3::installedThemes() const
 {
     QFileInfoList availableThemes;
-    foreach(const QString& themesDir, KGlobal::dirs()->findDirs("xdgdata-apps", "../themes")) {
+    foreach(const QString& themesDir, QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, "themes", QStandardPaths::LocateDirectory)) {
         QDir root(themesDir);
         availableThemes += root.entryInfoList(QDir::NoDotAndDotDot|QDir::AllDirs);
     }
@@ -51,17 +51,16 @@ QStringList AppearanceGTK3::installedThemes() const
     return themes;
 }
 
-bool AppearanceGTK3::saveSettings(const QString& file)
+bool AppearanceGTK3::saveSettings(const QString& file) const
 {
     //Opening GTK3 config file $ENV{XDG_CONFIG_HOME}/gtk-3.0/m_settings.ini
     QDir::home().mkpath(file.left(file.lastIndexOf('/'))); //we make sure the path exists
     QFile file_gtk3(file);
     
     if(!file_gtk3.open(QIODevice::WriteOnly | QIODevice::Text)) {
-        kDebug() << "Couldn't open GTK3 config file for writing at:" << file_gtk3.fileName();
+        qWarning() << "Couldn't open GTK3 config file for writing at:" << file_gtk3.fileName();
         return false;
     }
-    
     QTextStream flow3(&file_gtk3);
     flow3 << "[Settings]\n";
     flow3 << "gtk-font-name=" << m_settings["font"] << "\n";
@@ -69,9 +68,8 @@ bool AppearanceGTK3::saveSettings(const QString& file)
     flow3 << "gtk-icon-theme-name="<< m_settings["icon"] << "\n";
     flow3 << "gtk-fallback-icon-theme=" << m_settings["icon_fallback"] << "\n";
     flow3 << "gtk-toolbar-style=" << m_settings["toolbar_style"] << "\n";
-    flow3 << "gtk-menu-images=" << m_settings["show_icons_buttons"] << "\n";
-    flow3 << "gtk-button-images=" << m_settings["show_icons_menus"] << "\n";
-    
+    flow3 << "gtk-menu-images=" << m_settings["show_icons_menus"] << "\n";
+    flow3 << "gtk-button-images=" << m_settings["show_icons_buttons"] << "\n";
     return true;
 }
 
@@ -81,7 +79,7 @@ bool AppearanceGTK3::loadSettings(const QString& path)
     bool canRead=fileGtk3.open(QIODevice::ReadOnly | QIODevice::Text);
     
     if(canRead) {
-        QMap<QString, QString> foundSettings = readSettingsTuples(&fileGtk3);
+        const QMap<QString, QString> foundSettings = readSettingsTuples(&fileGtk3);
         
         m_settings["theme"] = foundSettings["gtk-theme-name"];
         m_settings["icon"] = foundSettings["gtk-icon-theme-name"];
@@ -92,14 +90,14 @@ bool AppearanceGTK3::loadSettings(const QString& path)
         m_settings["show_icons_buttons"] = foundSettings.value("gtk-button-images", "0");
         m_settings["show_icons_menus"] = foundSettings.value("gtk-menu-images", "0");
     } else
-        kDebug() << "Cannot open the GTK3 config file" << path;
+        qWarning() << "Cannot open the GTK3 config file" << path;
     
     return canRead;
 }
 
 QString AppearanceGTK3::defaultConfigFile() const
 {
-    QString root = KGlobal::dirs()->localxdgconfdir();
+    QString root = QStandardPaths::writableLocation(QStandardPaths::GenericConfigLocation);
     if(root.isEmpty())
         root = QFileInfo(QDir::home(), ".config").absoluteFilePath();
     
