@@ -22,20 +22,22 @@
 
 #include "gtkconfigkcmodule.h"
 #include <kaboutdata.h>
-#include <KGenericFactory>
 #include <KPluginFactory>
 #include <KProcess>
-#include <KStandardDirs>
 #include <KMessageBox>
-#include <QtGui>
-#include <QX11EmbedContainer>
+#include <KIconTheme>
+#include <KLocalizedString>
+#include <QStandardPaths>
+#include <QFile>
+#include <QMenu>
+#include <QDebug>
+#include <QDir>
 #include "ui_gui.h"
 #include "abstractappearance.h"
 #include "iconthemesmodel.h"
-#include <kicontheme.h>
+#include "fontshelpers.h"
 
-K_PLUGIN_FACTORY(GTKConfigKCModuleFactory, registerPlugin<GTKConfigKCModule>();)
-K_EXPORT_PLUGIN(GTKConfigKCModuleFactory("cgc","kde-gtk-config"))
+K_PLUGIN_FACTORY_WITH_JSON(GTKConfigKCModuleFactory, "kde-gtk-config.json", registerPlugin<GTKConfigKCModule>();)
 
 QMap<QString, int> gtkToolbarInit()
 {
@@ -50,21 +52,21 @@ QMap<QString, int> gtkToolbarInit()
 static QMap<QString, int> gtkToolbar = gtkToolbarInit();
 
 GTKConfigKCModule::GTKConfigKCModule(QWidget* parent, const QVariantList& args )
-    : KCModule(GTKConfigKCModuleFactory::componentData(), parent)
+    : KCModule(parent)
     , ui(new Ui::GUI)
     , installer(0)
     , uninstaller(0)
     , m_saveEnabled(true)
 {
     Q_UNUSED(args);
-    KAboutData *acercade = new KAboutData("cgc","kcm_cgc",ki18n("KDE GTK Config"), "2.2.1",
-                    ki18n("Configure your GTK Applications"),
-                    KAboutData::License_LGPL_V3,
-                    ki18n("Copyright 2011 José Antonio Sánchez Reynaga"));
-    acercade->addAuthor(ki18n("José Antonio Sánchez Reynaga (antonioJASR)"),ki18n("Main Developer"), "joanzare@gmail.com");
-    acercade->addAuthor(ki18n("Aleix Pol i Gonzalez"), ki18n("Feature development. Previews, code refactoring."), "aleixpol@blue-systems.com");
-    acercade->addCredit(ki18n("Manuel Tortosa (manutortosa)"), ki18n("Ideas, tester, internationalization"));
-    acercade->addCredit(ki18n("Adrián Chaves Fernández (Gallaecio)"), ki18n("Internationalization"));
+    KAboutData *acercade = new KAboutData("cgc", i18n("KDE GTK Config"), "2.2.1",
+                    i18n("Configure your GTK Applications"),
+                    KAboutLicense::LGPL_V3,
+                    i18n("Copyright 2011 José Antonio Sánchez Reynaga"));
+    acercade->addAuthor(i18n("José Antonio Sánchez Reynaga (antonioJASR)"),i18n("Main Developer"), "joanzare@gmail.com");
+    acercade->addAuthor(i18n("Aleix Pol i Gonzalez"), i18n("Feature development. Previews, code refactoring."), "aleixpol@blue-systems.com");
+    acercade->addCredit(i18n("Manuel Tortosa (manutortosa)"), i18n("Ideas, tester, internationalization"));
+    acercade->addCredit(i18n("Adrián Chaves Fernández (Gallaecio)"), i18n("Internationalization"));
     setAboutData(acercade);
     
     ui->setupUi(this);
@@ -73,15 +75,15 @@ GTKConfigKCModule::GTKConfigKCModule(QWidget* parent, const QVariantList& args )
     ui->cb_icon->setModel(m_iconsModel);
     ui->cb_icon_fallback->setModel(m_iconsModel);
     
-    m_tempGtk2Preview = KGlobal::dirs()->saveLocation("tmp", "gtkrc-2.0", false);
-    m_tempGtk3Preview = KGlobal::dirs()->saveLocation("tmp", ".config/gtk-3.0/settings.ini", false);
+    m_tempGtk2Preview = QStandardPaths::writableLocation(QStandardPaths::TempLocation)+ "/gtkrc-2.0";
+    m_tempGtk3Preview = QStandardPaths::writableLocation(QStandardPaths::TempLocation)+ ".config/gtk-3.0/settings.ini";
     
-    const KIcon previewIcon("document-preview");
+    const QIcon previewIcon = QIcon::fromTheme("document-preview");
     ui->gtk2Preview->setIcon(previewIcon);
     ui->gtk3Preview->setIcon(previewIcon);
     
-    QString gtk2Preview = KStandardDirs::findExe("gtk_preview");
-    QString gtk3Preview = KStandardDirs::findExe("gtk3_preview");
+    QString gtk2Preview = QStandardPaths::findExecutable("gtk_preview");
+    QString gtk3Preview = QStandardPaths::findExecutable("gtk3_preview");
     
     m_p2 = new KProcess(this);
     m_p2->setEnv("GTK2_RC_FILES", m_tempGtk2Preview, true);
@@ -91,7 +93,7 @@ GTKConfigKCModule::GTKConfigKCModule(QWidget* parent, const QVariantList& args )
     }
     
     m_p3 = new KProcess(this);
-    m_p3->setEnv("XDG_CONFIG_HOME", KGlobal::dirs()->saveLocation("tmp", ".config"));
+    m_p3->setEnv("XDG_CONFIG_HOME", QStandardPaths::writableLocation(QStandardPaths::TempLocation)+"/.config");
     if(!gtk3Preview.isEmpty()) {
         *m_p3 << gtk3Preview;
         connect(m_p3, SIGNAL(finished(int)), this, SLOT(untogglePreview()));
@@ -117,12 +119,12 @@ GTKConfigKCModule::GTKConfigKCModule(QWidget* parent, const QVariantList& args )
     connect(ui->gtk3Preview, SIGNAL(clicked(bool)), this, SLOT(runGtk3IfNecessary(bool)));
     
     QMenu* m = new QMenu(this);
-    m->addAction(KIcon("get-hot-new-stuff"), i18n("Download GTK2 themes..."), this, SLOT(showThemeGHNS()));
-    m->addAction(KIcon("get-hot-new-stuff"), i18n("Download GTK3 themes..."), this, SLOT(installThemeGTK3GHNS()));
-    m->addAction(KIcon("archive-insert"), i18n("Install a local theme..."), this, SLOT(showDialogForInstall()));
-    m->addAction(KIcon("archive-remove"), i18n("Uninstall a local theme..."), this, SLOT(showDialogForUninstall()));
+    m->addAction(QIcon::fromTheme("get-hot-new-stuff"), i18n("Download GTK2 themes..."), this, SLOT(showThemeGHNS()));
+    m->addAction(QIcon::fromTheme("get-hot-new-stuff"), i18n("Download GTK3 themes..."), this, SLOT(installThemeGTK3GHNS()));
+    m->addAction(QIcon::fromTheme("archive-insert"), i18n("Install a local theme..."), this, SLOT(showDialogForInstall()));
+    m->addAction(QIcon::fromTheme("archive-remove"), i18n("Uninstall a local theme..."), this, SLOT(showDialogForUninstall()));
     ui->newThemes->setMenu(m);
-    ui->newThemes->setIcon(KIcon("download"));
+    ui->newThemes->setIcon(QIcon::fromTheme("download"));
 }
 
 GTKConfigKCModule::~GTKConfigKCModule()
@@ -139,11 +141,6 @@ GTKConfigKCModule::~GTKConfigKCModule()
     delete ui;
 }
 
-QString fontToString(const QFont& f)
-{
-    return f.family() + ' ' + f.styleName() + ' ' + QString::number(f.pointSize());
-}
-
 void GTKConfigKCModule::syncUI()
 {
     appareance->setThemeGtk3(ui->cb_theme_gtk3->currentText());
@@ -173,27 +170,6 @@ void GTKConfigKCModule::installThemeGTK3GHNS()
      }
 }
 
-QFont stringToFont(const QString& font)
-{
-    QFontDatabase fdb;
-    QString fontFamily;
-    int familyIdx=-1;
-    for(int idx=font.indexOf(' '); idx<font.size(); idx=font.indexOf(' ', idx+1)) {
-        QString testFont = font.left(idx);
-        if(!fdb.hasFamily(testFont))
-            break;
-        fontFamily = testFont;
-        familyIdx = idx;
-    }
-    QRegExp fontRx(QString("( [a-zA-Z ]*) +([0-9]+)$"));
-    fontRx.indexIn(font, familyIdx);
-
-    QString fontStyle = fontRx.cap(1).trimmed();
-    int fontSize = fontRx.cap(2).toInt();
-    
-    return fdb.font(fontFamily, fontStyle, fontSize);
-}
-
 void GTKConfigKCModule::refreshLists()
 {
     refreshThemesUi(true);
@@ -216,7 +192,7 @@ void tryIcon(QLabel* label, const QString& fallback, const QString& theme, const
     
     QString ret;
     if(!theme.isEmpty())
-        ret = IconThemesModel::findIconRecursivelyByName(iconName, theme);
+        ret = IconThemesModel::findIconRecursivelyByName(iconName, QDir(theme));
     
     if(!ret.isEmpty()) {
         QPixmap p(ret);
@@ -235,11 +211,11 @@ void tryIcon(QLabel* label, const QString& fallback, const QString& theme, const
         return;
     }
     
-    KIcon notFoundIcon("application-x-zerosize");
+    QIcon notFoundIcon = QIcon::fromTheme("application-x-zerosize");
     QPixmap noIcon(notFoundIcon.pixmap(48,48));
     label->setPixmap(noIcon);
     
-    kDebug() << "could not find icon" << iconName;
+    qWarning() << "could not find icon" << iconName;
 }
 
 void GTKConfigKCModule::makePreviewIconTheme()
@@ -272,7 +248,7 @@ void GTKConfigKCModule::savePreviewConfig()
 {
     if(!m_saveEnabled || !(ui->gtk2Preview->isChecked() || ui->gtk3Preview->isChecked()))
         return;
-    kDebug() << "saving UI...";
+//     qDebug() << "saving UI...";
     
     syncUI();
     
@@ -329,7 +305,7 @@ void GTKConfigKCModule::runGtk3IfNecessary(bool checked)
 
 void GTKConfigKCModule::save()
 {
-    kDebug() << "******************************************* INSTALLATION :\n"
+/*    qDebug() << "******************************************* INSTALLATION :\n"
             << "theme : " << appareance->getTheme() << "\n"
             << "themeGTK3 : " << appareance->getThemeGtk3() << "\n"
             << "icons : " << appareance->getIcon() << "\n"
@@ -339,6 +315,7 @@ void GTKConfigKCModule::save()
             << "icons in buttons : " << appareance->getShowIconsInButtons() << "\n"
             << "icons in menus : " << appareance->getShowIconsInMenus() << "\n"
             << "********************************************************";
+    */
     syncUI();
     if(!appareance->saveFileConfig())
         KMessageBox::error(this, i18n("It was not possible to save the config"));
@@ -359,7 +336,7 @@ void GTKConfigKCModule::defaults()
 {
     refreshThemesUi(false);
 
-    kDebug() << "loading defaults...";
+//     qDebug() << "loading defaults...";
     m_saveEnabled = false;
     ui->font->setFont(font());
     bool showIcons = !QCoreApplication::testAttribute(Qt::AA_DontShowIconsInMenus);
@@ -464,3 +441,5 @@ void GTKConfigKCModule::untogglePreview()
     else
         ui->gtk3Preview->setChecked(false);
 }
+
+#include "gtkconfigkcmodule.moc"
